# opendaq-python / docs

General project documentation and function description files.

Go to [openDAQ documentation](http://opendaq-python.readthedocs.io/en/latest/ "DAQ.py walkthrough") in ReadTheDocs to take a look at these files.





